==> dispmua_1.6.8.orig.tar.bz2: dispmua-1.6.8/chrome/chrome.jar!/content/data-6f.js <==
dispMUA.arDispMUAAllocation["o"] =
{
  "o3sis o2 communication center mail" : [ "o2.png" , "http://www.o2.com/" ] ,
  "outlook connector for mdaemon" : [ "outlook_connector_mdaemon.png" , "http://www.altn.com/Products/CollaborationSolutions/OutlookConnector/" ] ,
  "ocxqmail from flicks software" : [ "flicks_software.png" , "http://www.flicks.com/ocxQmail/" ] ,
  "octeth email manager pro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "openwave webengine" : [ "openwave.png" , "http://www.openwave.com/" ] ,
  "online.net webmail" : [ "roundcube.png" , "http://www.roundcube.net/" ] ,
  "otrs mail service" : [ "otrs.png" , "http://otrs.org/" ] ,
  "opengroupware.org" : [ "opengroupware.png" , "http://opengroupware.org/" ] ,
  "office.freenet.de" : [ "freenet.png" , "http://office.freenet.de/" ] ,
  "outlook express" : [ "ms_outlook_express.png" , "http://www.microsoft.com/" ] ,
  "orbiz digitrade" : [ "orbiz.png" , "http://www.orbiz.com/Online-Shop-Software--7d.html" ] ,
  "one.com webmail" : [ "one_com.png" , "http://www.one.com/" ] ,
  "ostrosoft smtp" : [ "ostrosoft_smtp.png" , "http://www.ostrosoft.com/" ] ,
  "osc/erp-mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "openoffice.org" : [ "openoffice.png" , "http://www.openoffice.org/" ] ,
  "ogilvy express" : [ "ogilvy-express.png" , "http://www.ogilvy.com/" ] ,
  "openetworks.pl" : [ "openetworks_pl.png" , "http://www.openetworks.pl/" ] ,
  "online mailer" : [ "onlinemailer.png" , "http://www.onlinepublisher.nl/onlinemailer.asp" ] ,
  "o2.pl webmail" : [ "o2_pl.png" , "http://www.o2.pl/" ] ,
  "oz.by mailer" : [ "oz_by.png" , "http://oz.by/" ] ,
  "opensmtp.net" : [ "opensmtp-net.png" , "http://sourceforge.net/projects/opensmtp-net/" ] ,
  "open-xchange" : [ "open_xchange.png" , "http://www.open-xchange.com/" ] ,
  "open webmail" : [ "openwebmail.png" , "http://openwebmail.org/" ] ,
  "oikal-web.de" : [ "oikal.png" , "http://oikal-web.de/" ] ,
  "oe powertool" : [ "oe_powertool.png" , "http://www.grzegorz.net/oe/oept.php" ] ,
  "orbitixmail" : [ "orbitix.png" , "http://www.orbitix.com/" ] ,
  "openwebmail" : [ "openwebmail.png" , "http://openwebmail.org/" ] ,
  "openphpnuke" : [ "openphpnuke.png" , "http://www.openphpnuke.com/" ] ,
  "open-realty" : [ "open-realty.png" , "http://www.open-realty.org/" ] ,
  "onix oxmail" : [ "onix.png" , "http://www.onix.it/" ] ,
  "onet.poczta" : [ "onet_pl.png" , "http://poczta.onet.pl/" ] ,
  "omnitracker" : [ "omnitracker.png" , "http://www.omninet.de/" ] ,
  "osso email" : [ "osso-email.png" , "https://stage.maemo.org/svn/maemo/projects/email/osso-email/trunk/" ] ,
  "oscommerce" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "osc mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "one mailer" : [ "onemailer_com.png" , "http://www.onemailer.com/" ] ,
  "omnimailer" : [ "omnigate.png" , "http://www.omnigate.it/auto.aspx?cid=1256" ] ,
  "officetalk" : [ "officetalk.png" , "http://www.softalkltd.com/products/officetalk" ] ,
  "operamail" : [ "opera.png" , "http://www.operamail.com/" ] ,
  "online.ua" : [ "online_ua.png" , "http://www.online.ua/" ] ,
  "omnixmail" : [ "omnixmail.png" , "http://www.eraomnix.pl/pl/contact/email" ] ,
  "osticket" : [ "osticket.png" , "http://osticket.com/" ] ,
  "oomailer" : [ "ooshop_com.png" , "http://www.ooshop.com/" ] ,
  "onlywire" : [ "onlywire.png" , "http://onlywire.com/" ] ,
  "ocamlnet" : [ "caml.png" , "http://ocamlnet.sourceforge.net/" ] ,
  "openemm" : [ "openemm.png" , "http://www.openemm.org/" ] ,
  "onliner" : [ "onliner_ru.png" , "http://www.onliner.ru/" ] ,
  "oracle" : [ "oracle.png" , "http://www.oracle.com/" ] ,
  "openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "oempro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "ordis" : [ "ordis.png" , "http://www.ordis.cz/" ] ,
  "opera" : [ "opera.png" , "http://www.opera.com/products/desktop/m2/" ] ,
  "omail" : [ "omail.png" , "http://omail.omnis.ch/" ] ,
  "ontap" : [ "netapp.png" , "http://www.netapp.com/" ] ,
  "ozum" : [ "ozum.png" , "http://www.ozinsight.com/client/" ] ,
  "ovh" : [ "ovh.png" , "http://www.ovh.com/" ] ,
  "oe3" : [ "oe3.png" , "http://oe3.orf.at/" ] ,
}

==> dispmua_1.6.9.orig.tar.bz2: dispmua-1.6.9/chrome/chrome.jar!/content/data-6f.js <==
dispMUA.arDispMUAAllocation["o"] =
{
  "o3sis o2 communication center mail" : [ "o2.png" , "http://www.o2.com/" ] ,
  "outlook connector for mdaemon" : [ "outlook_connector_mdaemon.png" , "http://www.altn.com/Products/CollaborationSolutions/OutlookConnector/" ] ,
  "ocxqmail from flicks software" : [ "flicks_software.png" , "http://www.flicks.com/ocxQmail/" ] ,
  "octeth email manager pro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "openwave webengine" : [ "openwave.png" , "http://www.openwave.com/" ] ,
  "online.net webmail" : [ "roundcube.png" , "http://www.roundcube.net/" ] ,
  "otrs mail service" : [ "otrs.png" , "http://otrs.org/" ] ,
  "opengroupware.org" : [ "opengroupware.png" , "http://opengroupware.org/" ] ,
  "office.freenet.de" : [ "freenet.png" , "http://office.freenet.de/" ] ,
  "outlook express" : [ "ms_outlook_express.png" , "http://www.microsoft.com/" ] ,
  "orbiz digitrade" : [ "orbiz.png" , "http://www.orbiz.com/Online-Shop-Software--7d.html" ] ,
  "one.com webmail" : [ "one_com.png" , "http://www.one.com/" ] ,
  "ostrosoft smtp" : [ "ostrosoft_smtp.png" , "http://www.ostrosoft.com/" ] ,
  "osc/erp-mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "openoffice.org" : [ "openoffice.png" , "http://www.openoffice.org/" ] ,
  "ogilvy express" : [ "ogilvy-express.png" , "http://www.ogilvy.com/" ] ,
  "openetworks.pl" : [ "openetworks_pl.png" , "http://www.openetworks.pl/" ] ,
  "online mailer" : [ "onlinemailer.png" , "http://www.onlinepublisher.nl/onlinemailer.asp" ] ,
  "o2.pl webmail" : [ "o2_pl.png" , "http://www.o2.pl/" ] ,
  "oz.by mailer" : [ "oz_by.png" , "http://oz.by/" ] ,
  "opensmtp.net" : [ "opensmtp-net.png" , "http://sourceforge.net/projects/opensmtp-net/" ] ,
  "open-xchange" : [ "open_xchange.png" , "http://www.open-xchange.com/" ] ,
  "open webmail" : [ "openwebmail.png" , "http://openwebmail.org/" ] ,
  "oikal-web.de" : [ "oikal.png" , "http://oikal-web.de/" ] ,
  "oe powertool" : [ "oe_powertool.png" , "http://www.grzegorz.net/oe/oept.php" ] ,
  "orbitixmail" : [ "orbitix.png" , "http://www.orbitix.com/" ] ,
  "openwebmail" : [ "openwebmail.png" , "http://openwebmail.org/" ] ,
  "openphpnuke" : [ "openphpnuke.png" , "http://www.openphpnuke.com/" ] ,
  "open-realty" : [ "open-realty.png" , "http://www.open-realty.org/" ] ,
  "onix oxmail" : [ "onix.png" , "http://www.onix.it/" ] ,
  "onet.poczta" : [ "onet_pl.png" , "http://poczta.onet.pl/" ] ,
  "omnitracker" : [ "omnitracker.png" , "http://www.omninet.de/" ] ,
  "osso email" : [ "osso-email.png" , "https://stage.maemo.org/svn/maemo/projects/email/osso-email/trunk/" ] ,
  "oscommerce" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "osc mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "one mailer" : [ "onemailer_com.png" , "http://www.onemailer.com/" ] ,
  "omnimailer" : [ "omnigate.png" , "http://www.omnigate.it/auto.aspx?cid=1256" ] ,
  "officetalk" : [ "officetalk.png" , "http://www.softalkltd.com/products/officetalk" ] ,
  "operamail" : [ "operamail.png" , "http://www.operamail.com/" ] ,
  "online.ua" : [ "online_ua.png" , "http://www.online.ua/" ] ,
  "omnixmail" : [ "omnixmail.png" , "http://www.eraomnix.pl/pl/contact/email" ] ,
  "osticket" : [ "osticket.png" , "http://osticket.com/" ] ,
  "oomailer" : [ "ooshop_com.png" , "http://www.ooshop.com/" ] ,
  "onlywire" : [ "onlywire.png" , "http://onlywire.com/" ] ,
  "ocamlnet" : [ "caml.png" , "http://ocamlnet.sourceforge.net/" ] ,
  "openemm" : [ "openemm.png" , "http://www.openemm.org/" ] ,
  "onliner" : [ "onliner_ru.png" , "http://www.onliner.ru/" ] ,
  "oracle" : [ "oracle.png" , "http://www.oracle.com/" ] ,
  "openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "oempro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "ordis" : [ "ordis.png" , "http://www.ordis.cz/" ] ,
  "opera" : [ "operamail.png" , "http://www.opera.com/products/desktop/m2/" ] ,
  "omail" : [ "omail.png" , "http://omail.omnis.ch/" ] ,
  "ontap" : [ "netapp.png" , "http://www.netapp.com/" ] ,
  "ozum" : [ "ozum.png" , "http://www.ozinsight.com/client/" ] ,
  "ovh" : [ "ovh.png" , "http://www.ovh.com/" ] ,
  "oe3" : [ "oe3.png" , "http://oe3.orf.at/" ] ,
}
